/* $Id: mesh.h,v 2.0 1998/03/25 05:43:54 svmcguir Exp $ */

typedef struct{
  /* meshData structure.
   *
   * Contains an optionData structure and other data for performing the
   * stochastic mesh algorithm.
   *
   * meshPaths                  The first meshPath paths in the optionData
   *                            structure will be used for the mesh estimate.
   *                            The remaining paths only for the path estimate.
   *
   * valueIfHeld[time][path]    The value expected to be obtained by holding
   *                            the option instead of exercising it.
   *
   * value[time][path]          The value of the option.  The greater of the
   *                            value from holding and that from exercising.
   *
   * weightMeasure1             Measure of effective number of points averaged
   *                             over as described by GCF.
   *
   * weightMeasure2             Another measure of effective number of points
   *
   * weightMeasure3             Same as 2, but don't divide by the max  
   *
   * distribution[time][path]   The height of the distribution from which 
   *                            points are selected at [time][path].  g from 
   *                            eq. 18.
   *
   * reps                       The number of times to repeat estimate.
   *
   * innerControl               Which inner control to use.
   *
   * variance[time][path]       Variance of the Monte Carlo estimate of 
   *                            valueIfHeld[time][path].
   */

  int meshPaths;
  double **valueIfHeld;
  double **value;
  double *weightMeasure1;
  double *weightMeasure2;
  double *weightMeasure3;
  double **distribution;
  int reps;
  int innerControl;
  double **variance;

  /* Permanent scratch variables. */
  double **tp, *sum;
  FILE *weightfile;
  FILE *errorfile;

}meshData;

void meshDataAllocate(meshData *md, optionData *od, pathData *pd);

void meshSetFinalValue(meshData *md, optionData *od, pathData *pd);
